@@ -10,6 +10,7 @@ from logging import (
 )
 
 from .logger import KomoLogger
+NETWORK = DEBUG + 6
 
 
 def log_encoder(obj):
@@ -26,7 +27,9 @@ __all__ = [
     "WARNING",
     "ERROR",
     "CRITICAL",
+    "NETWORK",
     "KomoLogger",
     "log_encoder"
 ]
 logging.setLoggerClass(KomoLogger)
+logging.addLevelName(NETWORK, "NETWORK")
